# phase_paper

phase diagram Paper

Paper files are in tex/
To run figure making scripts, install this as a pip package with 'pip install -e <<path/to/oscillations_paper>>'

For windows machines do 'pip install <<path/to/oscillations_paper>> --user'

Other python dependencies (will be auto-installed by pip):
Matplotlib
Seaborn
